#!/usr/bin/env perl -w
use strict;
use warnings;
# nothing to test. but make sure that the modules can be compiled at least.
use Test::Sys::Info;
use Test::Sys::Info::Driver;
use Test::More;

ok(1, 'Fake test');
